@@ -19,10 +19,13 @@
 #ifndef KOMPARESHELL_H
 #define KOMPARESHELL_H
 
-#include <kapplication.h>
 #include <kparts/mainwindow.h>
 #include <kompare.h>
 
+#include <QLoggingCategory>
+
+Q_DECLARE_LOGGING_CATEGORY(KOMPARESHELL)
+
 class KompareInterface;
 namespace KParts {
     class ReadOnlyPart;
@@ -33,6 +36,8 @@ class KToggleAction;
 class KSqueezedTextLabel;
 class KomparePart;
 class KompareNavTreePart;
+class QLabel;
+class QEventLoopLocker;
 
 namespace KTextEditor {
 	class Document;
@@ -68,7 +73,7 @@ public:
 	/**
 	 * Use this method to load whatever file/URL you have
 	 */
-	void openDiff( const KUrl& url );
+	void openDiff( const QUrl& url );
 
 	/**
 	 * Use this method to load the diff from stdin
@@ -78,12 +83,12 @@ public:
 	/**
 	 * Use this method to compare 2 URLs (files or directories)
 	 */
-	void compare( const KUrl& source, const KUrl& destination );
+	void compare( const QUrl& source, const QUrl& destination );
 
 	/**
 	 * Use this method to blend diff into url1 (file or directory)
 	 */
-	void blend( const KUrl& url1, const KUrl& diff );
+	void blend( const QUrl& url1, const QUrl& diff );
 
 public slots:
 	void slotUpdateStatusBar( int modelIndex, int differenceIndex, int modelCount, int differenceCount, int appliedCount );
@@ -125,9 +130,9 @@ private:
 	void setupStatusBar();
 
 private:
-	KUrl                        m_sourceURL;
-	KUrl                        m_destinationURL;
-	KUrl                        m_diffURL;
+	QUrl                        m_sourceURL;
+	QUrl                        m_destinationURL;
+	QUrl                        m_diffURL;
 
 	KParts::ReadWritePart*      m_viewPart;
 	KParts::ReadOnlyPart*         m_navTreePart;
@@ -145,6 +150,9 @@ private:
 	KSqueezedTextLabel*         m_generalLabel;
 
 	QString                     m_diffString;
+	QLabel*                     m_filesLabel;
+	QLabel*                     m_differencesLabel;
+	QEventLoopLocker*           m_eventLoopLocker;
 };
 
 #endif // KOMPARE_H
