@@ -181,7 +181,7 @@ void KomparePart::setupActions()
 	m_diffRefresh = actionCollection()->addAction("file_refreshdiff", this, SLOT(slotRefreshDiff()));
 	m_diffRefresh->setIcon(QIcon::fromTheme("view-refresh"));
 	m_diffRefresh->setText(i18n("Refresh Diff"));
-	m_diffRefresh->setShortcuts(KStandardShortcut::reload());
+	actionCollection()->setDefaultShortcuts(m_diffRefresh, KStandardShortcut::reload());
 
 	m_print        = actionCollection()->addAction(KStandardAction::Print, this, SLOT( slotFilePrint() ));
 	m_printPreview = actionCollection()->addAction(KStandardAction::PrintPreview, this, SLOT( slotFilePrintPreview() ));
@@ -540,12 +540,15 @@ void KomparePart::saveDiff()
 	dlg.setModal( true );
 	dlg.setWindowTitle( i18n("Diff Options") );
 	QDialogButtonBox *buttons = new QDialogButtonBox( QDialogButtonBox::Save | QDialogButtonBox::Cancel, &dlg );
+	connect(buttons, &QDialogButtonBox::accepted, &dlg, &QDialog::accept);
+	connect(buttons, &QDialogButtonBox::rejected, &dlg, &QDialog::reject);
 	KompareSaveOptionsWidget* w = new KompareSaveOptionsWidget(
 	                                             m_info.localSource,
 	                                             m_info.localDestination,
 	                                             m_diffSettings, &dlg );
-	QHBoxLayout *layout = new QHBoxLayout(&dlg);
+	QVBoxLayout *layout = new QVBoxLayout(&dlg);
 	layout->addWidget( w );
+	layout->addWidget( buttons );
 	dlg.setLayout( layout );
 
 	if( dlg.exec() ) {
