@@ -18,7 +18,6 @@
 #ifndef KOMPARESAVEOPTIONSWIDGET_H
 #define KOMPARESAVEOPTIONSWIDGET_H
 
-#include <kurl.h>
 #include <kompare.h>
 
 #include "komparesaveoptionsbase.h"
@@ -26,7 +25,7 @@
 class DiffSettings;
 class QButtonGroup;
 
-class KompareSaveOptionsWidget : public KompareSaveOptionsBase, public KompareFunctions
+class KompareSaveOptionsWidget : public KompareSaveOptionsBase
 {
 Q_OBJECT
 public:
